==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/CfnCodeDeployBlueGreenLifecycleEventHooks.java <==
package software.amazon.awscdk;

/**
 * Lifecycle events for blue-green deployments.
 * <p>
 * The type of the {&#64;link CfnCodeDeployBlueGreenHookProps.lifecycleEventHooks} property.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.*;
 * CfnCodeDeployBlueGreenLifecycleEventHooks cfnCodeDeployBlueGreenLifecycleEventHooks = CfnCodeDeployBlueGreenLifecycleEventHooks.builder()
 *         .afterAllowTestTraffic("afterAllowTestTraffic")
 *         .afterAllowTraffic("afterAllowTraffic")
 *         .afterInstall("afterInstall")
 *         .beforeAllowTraffic("beforeAllowTraffic")
 *         .beforeInstall("beforeInstall")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:08.188Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.CfnCodeDeployBlueGreenLifecycleEventHooks")
@software.amazon.jsii.Jsii.Proxy(CfnCodeDeployBlueGreenLifecycleEventHooks.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCodeDeployBlueGreenLifecycleEventHooks extends software.amazon.jsii.JsiiSerializable {

    /**
     * Function to use to run tasks after the test listener serves traffic to the replacement task set.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAfterAllowTestTraffic() {
        return null;
    }

    /**
     * Function to use to run tasks after the second target group serves traffic to the replacement task set.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAfterAllowTraffic() {
        return null;
    }

    /**
     * Function to use to run tasks after the replacement task set is created and one of the target groups is associated with it.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAfterInstall() {
        return null;
    }

    /**
     * Function to use to run tasks after the second target group is associated with the replacement task set, but before traffic is shifted to the replacement task set.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getBeforeAllowTraffic() {
        return null;
    }

    /**
     * Function to use to run tasks before the replacement task set is created.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getBeforeInstall() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCodeDeployBlueGreenLifecycleEventHooks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCodeDeployBlueGreenLifecycleEventHooks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCodeDeployBlueGreenLifecycleEventHooks> {
        java.lang.String afterAllowTestTraffic;
        java.lang.String afterAllowTraffic;
        java.lang.String afterInstall;
        java.lang.String beforeAllowTraffic;
        java.lang.String beforeInstall;

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getAfterAllowTestTraffic}
         * @param afterAllowTestTraffic Function to use to run tasks after the test listener serves traffic to the replacement task set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder afterAllowTestTraffic(java.lang.String afterAllowTestTraffic) {
            this.afterAllowTestTraffic = afterAllowTestTraffic;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getAfterAllowTraffic}
         * @param afterAllowTraffic Function to use to run tasks after the second target group serves traffic to the replacement task set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder afterAllowTraffic(java.lang.String afterAllowTraffic) {
            this.afterAllowTraffic = afterAllowTraffic;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getAfterInstall}
         * @param afterInstall Function to use to run tasks after the replacement task set is created and one of the target groups is associated with it.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder afterInstall(java.lang.String afterInstall) {
            this.afterInstall = afterInstall;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getBeforeAllowTraffic}
         * @param beforeAllowTraffic Function to use to run tasks after the second target group is associated with the replacement task set, but before traffic is shifted to the replacement task set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder beforeAllowTraffic(java.lang.String beforeAllowTraffic) {
            this.beforeAllowTraffic = beforeAllowTraffic;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getBeforeInstall}
         * @param beforeInstall Function to use to run tasks before the replacement task set is created.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder beforeInstall(java.lang.String beforeInstall) {
            this.beforeInstall = beforeInstall;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCodeDeployBlueGreenLifecycleEventHooks}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCodeDeployBlueGreenLifecycleEventHooks build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnCodeDeployBlueGreenLifecycleEventHooks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCodeDeployBlueGreenLifecycleEventHooks {
        private final java.lang.String afterAllowTestTraffic;
        private final java.lang.String afterAllowTraffic;
        private final java.lang.String afterInstall;
        private final java.lang.String beforeAllowTraffic;
        private final java.lang.String beforeInstall;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.afterAllowTestTraffic = software.amazon.jsii.Kernel.get(this, "afterAllowTestTraffic", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.afterAllowTraffic = software.amazon.jsii.Kernel.get(this, "afterAllowTraffic", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.afterInstall = software.amazon.jsii.Kernel.get(this, "afterInstall", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.beforeAllowTraffic = software.amazon.jsii.Kernel.get(this, "beforeAllowTraffic", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.beforeInstall = software.amazon.jsii.Kernel.get(this, "beforeInstall", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.afterAllowTestTraffic = builder.afterAllowTestTraffic;
            this.afterAllowTraffic = builder.afterAllowTraffic;
            this.afterInstall = builder.afterInstall;
            this.beforeAllowTraffic = builder.beforeAllowTraffic;
            this.beforeInstall = builder.beforeInstall;
        }

        @Override
        public final java.lang.String getAfterAllowTestTraffic() {
            return this.afterAllowTestTraffic;
        }

        @Override
        public final java.lang.String getAfterAllowTraffic() {
            return this.afterAllowTraffic;
        }

        @Override
        public final java.lang.String getAfterInstall() {
            return this.afterInstall;
        }

        @Override
        public final java.lang.String getBeforeAllowTraffic() {
            return this.beforeAllowTraffic;
        }

        @Override
        public final java.lang.String getBeforeInstall() {
            return this.beforeInstall;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAfterAllowTestTraffic() != null) {
                data.set("afterAllowTestTraffic", om.valueToTree(this.getAfterAllowTestTraffic()));
            }
            if (this.getAfterAllowTraffic() != null) {
                data.set("afterAllowTraffic", om.valueToTree(this.getAfterAllowTraffic()));
            }
            if (this.getAfterInstall() != null) {
                data.set("afterInstall", om.valueToTree(this.getAfterInstall()));
            }
            if (this.getBeforeAllowTraffic() != null) {
                data.set("beforeAllowTraffic", om.valueToTree(this.getBeforeAllowTraffic()));
            }
            if (this.getBeforeInstall() != null) {
                data.set("beforeInstall", om.valueToTree(this.getBeforeInstall()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.CfnCodeDeployBlueGreenLifecycleEventHooks"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCodeDeployBlueGreenLifecycleEventHooks.Jsii$Proxy that = (CfnCodeDeployBlueGreenLifecycleEventHooks.Jsii$Proxy) o;

            if (this.afterAllowTestTraffic != null ? !this.afterAllowTestTraffic.equals(that.afterAllowTestTraffic) : that.afterAllowTestTraffic != null) return false;
            if (this.afterAllowTraffic != null ? !this.afterAllowTraffic.equals(that.afterAllowTraffic) : that.afterAllowTraffic != null) return false;
            if (this.afterInstall != null ? !this.afterInstall.equals(that.afterInstall) : that.afterInstall != null) return false;
            if (this.beforeAllowTraffic != null ? !this.beforeAllowTraffic.equals(that.beforeAllowTraffic) : that.beforeAllowTraffic != null) return false;
            return this.beforeInstall != null ? this.beforeInstall.equals(that.beforeInstall) : that.beforeInstall == null;
        }

        @Override
        public final int hashCode() {
            int result = this.afterAllowTestTraffic != null ? this.afterAllowTestTraffic.hashCode() : 0;
            result = 31 * result + (this.afterAllowTraffic != null ? this.afterAllowTraffic.hashCode() : 0);
            result = 31 * result + (this.afterInstall != null ? this.afterInstall.hashCode() : 0);
            result = 31 * result + (this.beforeAllowTraffic != null ? this.beforeAllowTraffic.hashCode() : 0);
            result = 31 * result + (this.beforeInstall != null ? this.beforeInstall.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/CfnCodeDeployBlueGreenLifecycleEventHooks.java <==
package software.amazon.awscdk;

/**
 * Lifecycle events for blue-green deployments.
 * <p>
 * The type of the <code>CfnCodeDeployBlueGreenHookProps.lifecycleEventHooks</code> property.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.*;
 * CfnCodeDeployBlueGreenLifecycleEventHooks cfnCodeDeployBlueGreenLifecycleEventHooks = CfnCodeDeployBlueGreenLifecycleEventHooks.builder()
 *         .afterAllowTestTraffic("afterAllowTestTraffic")
 *         .afterAllowTraffic("afterAllowTraffic")
 *         .afterInstall("afterInstall")
 *         .beforeAllowTraffic("beforeAllowTraffic")
 *         .beforeInstall("beforeInstall")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:26.975Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.CfnCodeDeployBlueGreenLifecycleEventHooks")
@software.amazon.jsii.Jsii.Proxy(CfnCodeDeployBlueGreenLifecycleEventHooks.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCodeDeployBlueGreenLifecycleEventHooks extends software.amazon.jsii.JsiiSerializable {

    /**
     * Function to use to run tasks after the test listener serves traffic to the replacement task set.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAfterAllowTestTraffic() {
        return null;
    }

    /**
     * Function to use to run tasks after the second target group serves traffic to the replacement task set.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAfterAllowTraffic() {
        return null;
    }

    /**
     * Function to use to run tasks after the replacement task set is created and one of the target groups is associated with it.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAfterInstall() {
        return null;
    }

    /**
     * Function to use to run tasks after the second target group is associated with the replacement task set, but before traffic is shifted to the replacement task set.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getBeforeAllowTraffic() {
        return null;
    }

    /**
     * Function to use to run tasks before the replacement task set is created.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getBeforeInstall() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCodeDeployBlueGreenLifecycleEventHooks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCodeDeployBlueGreenLifecycleEventHooks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCodeDeployBlueGreenLifecycleEventHooks> {
        java.lang.String afterAllowTestTraffic;
        java.lang.String afterAllowTraffic;
        java.lang.String afterInstall;
        java.lang.String beforeAllowTraffic;
        java.lang.String beforeInstall;

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getAfterAllowTestTraffic}
         * @param afterAllowTestTraffic Function to use to run tasks after the test listener serves traffic to the replacement task set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder afterAllowTestTraffic(java.lang.String afterAllowTestTraffic) {
            this.afterAllowTestTraffic = afterAllowTestTraffic;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getAfterAllowTraffic}
         * @param afterAllowTraffic Function to use to run tasks after the second target group serves traffic to the replacement task set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder afterAllowTraffic(java.lang.String afterAllowTraffic) {
            this.afterAllowTraffic = afterAllowTraffic;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getAfterInstall}
         * @param afterInstall Function to use to run tasks after the replacement task set is created and one of the target groups is associated with it.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder afterInstall(java.lang.String afterInstall) {
            this.afterInstall = afterInstall;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getBeforeAllowTraffic}
         * @param beforeAllowTraffic Function to use to run tasks after the second target group is associated with the replacement task set, but before traffic is shifted to the replacement task set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder beforeAllowTraffic(java.lang.String beforeAllowTraffic) {
            this.beforeAllowTraffic = beforeAllowTraffic;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenLifecycleEventHooks#getBeforeInstall}
         * @param beforeInstall Function to use to run tasks before the replacement task set is created.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder beforeInstall(java.lang.String beforeInstall) {
            this.beforeInstall = beforeInstall;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCodeDeployBlueGreenLifecycleEventHooks}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCodeDeployBlueGreenLifecycleEventHooks build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnCodeDeployBlueGreenLifecycleEventHooks}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCodeDeployBlueGreenLifecycleEventHooks {
        private final java.lang.String afterAllowTestTraffic;
        private final java.lang.String afterAllowTraffic;
        private final java.lang.String afterInstall;
        private final java.lang.String beforeAllowTraffic;
        private final java.lang.String beforeInstall;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.afterAllowTestTraffic = software.amazon.jsii.Kernel.get(this, "afterAllowTestTraffic", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.afterAllowTraffic = software.amazon.jsii.Kernel.get(this, "afterAllowTraffic", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.afterInstall = software.amazon.jsii.Kernel.get(this, "afterInstall", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.beforeAllowTraffic = software.amazon.jsii.Kernel.get(this, "beforeAllowTraffic", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.beforeInstall = software.amazon.jsii.Kernel.get(this, "beforeInstall", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.afterAllowTestTraffic = builder.afterAllowTestTraffic;
            this.afterAllowTraffic = builder.afterAllowTraffic;
            this.afterInstall = builder.afterInstall;
            this.beforeAllowTraffic = builder.beforeAllowTraffic;
            this.beforeInstall = builder.beforeInstall;
        }

        @Override
        public final java.lang.String getAfterAllowTestTraffic() {
            return this.afterAllowTestTraffic;
        }

        @Override
        public final java.lang.String getAfterAllowTraffic() {
            return this.afterAllowTraffic;
        }

        @Override
        public final java.lang.String getAfterInstall() {
            return this.afterInstall;
        }

        @Override
        public final java.lang.String getBeforeAllowTraffic() {
            return this.beforeAllowTraffic;
        }

        @Override
        public final java.lang.String getBeforeInstall() {
            return this.beforeInstall;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAfterAllowTestTraffic() != null) {
                data.set("afterAllowTestTraffic", om.valueToTree(this.getAfterAllowTestTraffic()));
            }
            if (this.getAfterAllowTraffic() != null) {
                data.set("afterAllowTraffic", om.valueToTree(this.getAfterAllowTraffic()));
            }
            if (this.getAfterInstall() != null) {
                data.set("afterInstall", om.valueToTree(this.getAfterInstall()));
            }
            if (this.getBeforeAllowTraffic() != null) {
                data.set("beforeAllowTraffic", om.valueToTree(this.getBeforeAllowTraffic()));
            }
            if (this.getBeforeInstall() != null) {
                data.set("beforeInstall", om.valueToTree(this.getBeforeInstall()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.CfnCodeDeployBlueGreenLifecycleEventHooks"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCodeDeployBlueGreenLifecycleEventHooks.Jsii$Proxy that = (CfnCodeDeployBlueGreenLifecycleEventHooks.Jsii$Proxy) o;

            if (this.afterAllowTestTraffic != null ? !this.afterAllowTestTraffic.equals(that.afterAllowTestTraffic) : that.afterAllowTestTraffic != null) return false;
            if (this.afterAllowTraffic != null ? !this.afterAllowTraffic.equals(that.afterAllowTraffic) : that.afterAllowTraffic != null) return false;
            if (this.afterInstall != null ? !this.afterInstall.equals(that.afterInstall) : that.afterInstall != null) return false;
            if (this.beforeAllowTraffic != null ? !this.beforeAllowTraffic.equals(that.beforeAllowTraffic) : that.beforeAllowTraffic != null) return false;
            return this.beforeInstall != null ? this.beforeInstall.equals(that.beforeInstall) : that.beforeInstall == null;
        }

        @Override
        public final int hashCode() {
            int result = this.afterAllowTestTraffic != null ? this.afterAllowTestTraffic.hashCode() : 0;
            result = 31 * result + (this.afterAllowTraffic != null ? this.afterAllowTraffic.hashCode() : 0);
            result = 31 * result + (this.afterInstall != null ? this.afterInstall.hashCode() : 0);
            result = 31 * result + (this.beforeAllowTraffic != null ? this.beforeAllowTraffic.hashCode() : 0);
            result = 31 * result + (this.beforeInstall != null ? this.beforeInstall.hashCode() : 0);
            return result;
        }
    }
}
